ShimmerTheme class

Constructors

ShimmerTheme()
factory

Properties

baseColor Color
no setter
borderRadius double
no setter
direction ShimmerDirection
no setter
disableAfter Duration?
no setter
duration Duration
Getters
no setter
effect ShimmerEffect
no setter
hashCode int
The hash code for this object.
no setterinherited
height double
no setter
highlightColor Color
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shimmerAngle double
no setter
speedFactor double
no setter
width double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update({Duration? duration, double? angle, double? speedFactor, double? width, double? height, Color? baseColor, Color? highlightColor, ShimmerDirection? direction, ShimmerEffect? effect, Duration? disableAfter, double? borderRadius}) ShimmerTheme
Update method with borderRadius included

Operators

operator ==(Object other) bool
The equality operator.
inherited